@@ -1,6 +1,8 @@
 #' Confidence/Credible Interval (CI) Formatting
 #'
-#' @param CI_low Lower CI bound.
+#' @param CI_low Lower CI bound. Usually a numeric value, but can also be a
+#'    CI output returned `bayestestR`, in which case the remaining arguments
+#'    are unnecessary.
 #' @param CI_high Upper CI bound.
 #' @param ci CI level in percentage.
 #' @param brackets Either a logical, and if `TRUE` (default), values are
@@ -14,6 +16,9 @@
 #' @param width_low,width_high Like `width`, but only applies to the lower
 #'   or higher confidence interval value. This can be used when the values for
 #'   the lower and upper CI are of very different length.
+#' @param ci_string String to be used in the output to indicate the type of
+#' interval. Default is `"CI"`, but can be changed to `"HDI"` or anything else,
+#' if necessary.
 #' @inheritParams format_value
 #'
 #' @return A formatted string.
@@ -32,16 +37,25 @@
 #' x <- format_ci(c(1.205, 23.4, 100.43), c(3.57, -13.35, 9.4), width = "auto")
 #' cat(x, sep = "\n")
 #' @export
-format_ci <- function(CI_low,
-                      CI_high,
-                      ci = 0.95,
-                      digits = 2,
-                      brackets = TRUE,
-                      width = NULL,
-                      width_low = width,
-                      width_high = width,
-                      missing = "",
-                      zap_small = FALSE) {
+format_ci <- function(CI_low, ...) {
+  UseMethod("format_ci")
+}
+
+
+#' @rdname format_ci
+#' @export
+format_ci.numeric <- function(CI_low,
+                              CI_high,
+                              ci = 0.95,
+                              digits = 2,
+                              brackets = TRUE,
+                              width = NULL,
+                              width_low = width,
+                              width_high = width,
+                              missing = "",
+                              zap_small = FALSE,
+                              ci_string = "CI",
+                              ...) {
   # check proper defaults
   if (isTRUE(brackets)) {
     ci_brackets <- c("[", "]")
@@ -105,25 +119,7 @@ format_ci <- function(CI_low,
 
   if (is.na(missing)) missing <- NA_character_
 
-  if (!is.null(ci)) {
-    ifelse(is.na(CI_low) & is.na(CI_high),
-      missing,
-      paste0(
-        ci * 100,
-        "% CI ",
-        .format_ci(
-          CI_low,
-          CI_high,
-          digits = digits,
-          ci_brackets = ci_brackets,
-          width_low = width_low,
-          width_high = width_high,
-          missing = missing,
-          zap_small = zap_small
-        )
-      )
-    )
-  } else {
+  if (is.null(ci)) {
     ifelse(
       is.na(CI_low) & is.na(CI_high),
       missing,
@@ -138,9 +134,76 @@ format_ci <- function(CI_low,
         zap_small = zap_small
       )
     )
+  } else {
+    ifelse(is.na(CI_low) & is.na(CI_high),
+      missing,
+      paste0(
+        ci * 100,
+        "% ",
+        ci_string,
+        " ",
+        .format_ci(
+          CI_low,
+          CI_high,
+          digits = digits,
+          ci_brackets = ci_brackets,
+          width_low = width_low,
+          width_high = width_high,
+          missing = missing,
+          zap_small = zap_small
+        )
+      )
+    )
   }
 }
 
+#' @export
+format_ci.factor <- format_ci.numeric
+
+#' @export
+format_ci.character <- format_ci.numeric
+
+
+# bayestestR objects ------------------------------------------------------
+
+#' @export
+format_ci.bayestestR_ci <- function(CI_low, ci_string = NULL, ...) {
+  # find default for ci_string
+  if (is.null(ci_string)) {
+    ci_string <- ifelse(inherits(CI_low, "bayestestR_hdi"), "HDI", "ETI")
+  }
+  x <- as.data.frame(CI_low)
+  format_ci(
+    CI_low = x$CI_low,
+    CI_high = x$CI_high,
+    ci = x$CI,
+    ci_string = ci_string,
+    ...
+  )
+}
+
+
+# data frames ------------------------------------------------------
+
+#' @export
+format_ci.data.frame <- function(CI_low, ci_string = "CI", ...) {
+  # nicer name
+  x <- CI_low
+  format_ci(
+    CI_low = x$CI_low,
+    CI_high = x$CI_high,
+    ci = x$CI,
+    ci_string = ci_string,
+    ...
+  )
+}
+
+
+
+
+# Convenience function ----------------------------------------------------
+
+
 #' @keywords internal
 .format_ci <- function(CI_low,
                        CI_high,
