@@ -1,11 +1,11 @@
-testthat::skip_on_cran()
-skip_if_not_or_load_if_installed("marginaleffects")
-skip_if_not_or_load_if_installed("emmeans")
+skip_on_cran()
+skip_if_not_installed("marginaleffects")
+skip_if_not_installed("emmeans")
 
 test_that("marginaleffects", {
   m <- lm(Sepal.Width ~ Species * Petal.Length, data = iris)
 
-  x <- marginaleffects(m,
+  x <- marginaleffects::slopes(m,
     variables = "Petal.Length",
     newdata = insight::get_datagrid(m, at = "Species")
   )
@@ -26,4 +26,15 @@ test_that("marginaleffects", {
 
   # Find statistic
   expect_identical(insight::find_statistic(x), "z-statistic")
+
+  # standardize names - "s.value" becomes "S"
+  skip_if_not_installed("parameters")
+  expect_named(
+    parameters::model_parameters(x),
+    c(
+      "rowid", "Parameter", "Coefficient", "SE", "Statistic", "p",
+      "S", "CI", "CI_low", "CI_high", "predicted_lo", "predicted_hi",
+      "Predicted", "Species", "Petal.Length", "Sepal.Width"
+    )
+  )
 })
